@@ -45,11 +45,10 @@ impl Account {
 
     /// Update the accounts state for the newest price data
     pub fn update(&mut self, price: f64, trade_timestamp: u64) {
-        self.acc_tracker.update(trade_timestamp, price);
         let upnl: f64 =
             self.futures_type
                 .pnl(self.position.entry_price(), price, self.position.size());
-        self.acc_tracker.log_upnl(upnl);
+        self.acc_tracker.update(trade_timestamp, price, upnl);
 
         self.position.update_state(price, self.futures_type);
     }
